from flask import Flask, request
from .oauth import oauth
from ._defaults import Defaults

def auth(secrets_file_contents, auth_root, **kwArgs):
  auth_app = Flask('google-flask-oauth')
  auth_app.config.from_object(Defaults)
  auth_app.config['AUTH_ROOT'] = auth_root
  auth_app.config['AUTH_SA_SECRET_CONTENTS'] = secrets_file_contents
  for key in kwArgs:
    auth_app.config['CUSTOM_{}'.format(key.upper())] = kwArgs[key]

  auth_app.register_blueprint(oauth)

  return auth_app

def aws_auth(**kwArgs):
  from ._aws_bootstrap import CLIENT_SECRET, AUTH_ROOT
  return auth(CLIENT_SECRET, AUTH_ROOT, **kwArgs)



from flask import Blueprint, request, jsonify, current_app
from google_auth_oauthlib.flow import Flow
from base64 import urlsafe_b64encode
import json
import logging

oauth = Blueprint('oauth', __name__)

def build_flow(state=None):
  flow = Flow.from_client_config(
    current_app.config['AUTH_SA_SECRET_CONTENTS'],
    ['openid', 'https://www.googleapis.com/auth/userinfo.email'],
    state=state
  )
  flow.redirect_uri = f'https://{current_app.config["AUTH_ROOT"]}/oauth/token'
  return flow

@oauth.route('/oauth/start', methods=['POST'])
def oauth_start():
  flow = build_flow()
  authorization_url, _ = flow.authorization_url(access_type='offline', include_granted_scopes='true')
  return jsonify({
    'redirect_url': authorization_url
  }), 200

@oauth.route('/oauth/exchange', methods=['POST'])
def oauth_exchange():
  req_data = request.get_json(force=True)
  code = req_data.get('code', '')
  state = req_data.get('state', '')
  if not code:
    return jsonify({'error': 'Must provide authorization code'}), 400
  if not state:
    return jsonify({'error': 'Must provide state'}), 400
  flow = build_flow(state)
  flow.fetch_token(code=code)
  credentials = flow.credentials
  logging.info(credentials)
  session = flow.authorized_session()
  logging.info(session.get('https://www.googleapis.com/userinfo/v2/me').json())

  assembled_credentials = {
    'token': credentials.token,
    'refresh_token': credentials.refresh_token
  }
  return jsonify({
    'token': urlsafe_b64encode(json.dumps(assembled_credentials).encode()).decode()
  }), 200



import setuptools

with open("README.md", "r") as fh:
  long_description = fh.read()

setuptools.setup(
  name="google-flask-oauth",
  version="0.0.1-dev18",
  author="Michael Madison",
  author_email="cadetstar@hotmail.com",
  description="Pseudo-application for simplifying the OAuth flow with Google",
  long_description=long_description,
  long_description_content_type="text/markdown",
  url="https://github.com/cadetstar/google-flask-oauth",
  packages=setuptools.find_packages(),
  install_requires=[
    'Flask==1.1.2',
    'google-api-python-client==1.11.0',
    'google_auth_oauthlib==0.4.1'
  ],
  classifiers=[
    "Programming Language :: Python :: 3",
    "License :: OSI Approved :: MIT License",
    "Operating System :: OS Independent",
  ],
  python_requires='>=3.6',
)


import os
import boto3
import json

_client = boto3.client('secretsmanager')
_secretname = os.getenv('OAUTH_CLIENT_SECRET_ID')

if _secretname:
  record = _client.get_secret_value(SecretId=_secretname)
  config = json.loads(record['SecretString'])

  CLIENT_SECRET = config['client_config']
  AUTH_ROOT = config['auth_root']
else:
  CLIENT_SECRET = ""
  AUTH_ROOT = ""